@@ -1,14 +1,20 @@
-/** Copyright (C) 2016 Tim Kuipers - Released under terms of the AGPLv3 License */
-#include "ConicalOverhang.h"
+//Copyright (c) 2016 Tim Kuipers
+//Copyright (c) 2018 Ultimaker B.V.
+//CuraEngine is released under the terms of the AGPLv3 or higher.
 
+#include "ConicalOverhang.h"
+#include "mesh.h"
+#include "slicer.h"
+#include "settings/types/AngleRadians.h" //To process the overhang angle.
 
 namespace cura {
 
-
-void ConicalOverhang::apply(Slicer* slicer, double angle, int layer_thickness)
+void ConicalOverhang::apply(Slicer* slicer, const Mesh& mesh)
 {
-    double tanAngle = tan(angle);  // the XY-component of the angle
-    int max_dist_from_lower_layer = tanAngle * layer_thickness; // max dist which can be bridged
+    const AngleRadians angle = mesh.settings.get<AngleRadians>("conical_overhang_angle");
+    const double tan_angle = tan(angle);  // the XY-component of the angle
+    const coord_t layer_thickness = mesh.settings.get<coord_t>("layer_height");
+    coord_t max_dist_from_lower_layer = tan_angle * layer_thickness; // max dist which can be bridged
 
     for (unsigned int layer_nr = slicer->layers.size() - 2; static_cast<int>(layer_nr) >= 0; layer_nr--)
     {
