@@ -1,13 +1,19 @@
-/** Copyright (C) 2016 Ultimaker - Released under terms of the AGPLv3 License */
+//Copyright (c) 2018 Ultimaker B.V.
+//CuraEngine is released under the terms of the AGPLv3 or higher.
+
 #ifndef G_CODE_PATH_CONFIG_H
 #define G_CODE_PATH_CONFIG_H
 
-#include "RetractionConfig.h"
 #include "PrintFeature.h"
+#include "settings/types/Ratio.h" //For flow rate.
+#include "settings/types/Velocity.h"
+#include "utils/Coord_t.h"
 
 namespace cura 
 {
 
+struct LayerIndex;
+
 /*!
  * The GCodePathConfig is the configuration for moves/extrusion actions. This defines at which width the line is printed and at which speed.
  */
@@ -19,21 +25,22 @@ public:
      */
     struct SpeedDerivatives
     {
-        double speed; //!< movement speed (mm/s)
-        double acceleration; //!< acceleration of head movement (mm/s^2)
-        double jerk; //!< jerk of the head movement (around stand still) as instantaneous speed change (mm/s)
+        Velocity speed; //!< movement speed (mm/s)
+        Acceleration acceleration; //!< acceleration of head movement (mm/s^2)
+        Velocity jerk; //!< jerk of the head movement (around stand still) as instantaneous speed change (mm/s)
     };
     const PrintFeatureType type; //!< name of the feature type
+    static constexpr double FAN_SPEED_DEFAULT = -1;
 private:
     SpeedDerivatives speed_derivatives; //!< The speed settings (and acceleration and jerk) of the extruded line. May be changed when smoothSpeed is called.
-    const int line_width; //!< width of the line extruded
-    const int layer_thickness; //!< current layer height in micron
-    const double flow; //!< extrusion flow modifier in %
+    const coord_t line_width; //!< width of the line extruded
+    const coord_t layer_thickness; //!< current layer height in micron
+    const Ratio flow; //!< extrusion flow modifier.
     const double extrusion_mm3_per_mm;//!< current mm^3 filament moved per mm line traversed
     const bool is_bridge_path; //!< whether current config is used when bridging
     const double fan_speed; //!< fan speed override for this path, value should be within range 0-100 (inclusive) and ignored otherwise
 public:
-    GCodePathConfig(PrintFeatureType type, int line_width, int layer_height, double flow, SpeedDerivatives speed_derivatives, bool is_bridge_path = false, double fan_speed = -1);
+    GCodePathConfig(const PrintFeatureType& type, const coord_t line_width, const coord_t layer_height, const Ratio& flow, const SpeedDerivatives speed_derivatives, const bool is_bridge_path = false, const double fan_speed = FAN_SPEED_DEFAULT);
 
     /*!
      * copy constructor
@@ -51,7 +58,7 @@ public:
      * \param layer_nr The layer number 
      * \param max_speed_layer The layer number for which the speed_iconic should be used.
      */
-    void smoothSpeed(SpeedDerivatives first_layer_config, int layer_nr, int max_speed_layer);
+    void smoothSpeed(SpeedDerivatives first_layer_config, const LayerIndex& layer_nr, const LayerIndex& max_speed_layer);
 
     /*!
      * Can only be called after the layer height has been set (which is done while writing the gcode!)
@@ -61,19 +68,19 @@ public:
     /*!
      * Get the movement speed in mm/s
      */
-    double getSpeed() const;
+    Velocity getSpeed() const;
 
     /*!
      * Get the current acceleration of this config
      */
-    double getAcceleration() const;
+    Acceleration getAcceleration() const;
 
     /*!
      * Get the current jerk of this config
      */
-    double getJerk() const;
+    Velocity getJerk() const;
 
-    int getLineWidth() const;
+    coord_t getLineWidth() const;
 
     bool isTravelPath() const;
 
@@ -81,9 +88,9 @@ public:
 
     double getFanSpeed() const;
 
-    double getFlowPercentage() const;
+    Ratio getFlowRatio() const;
 
-    int getLayerThickness() const;
+    coord_t getLayerThickness() const;
 
     const PrintFeatureType& getPrintFeatureType() const;
 
