@@ -1,72 +1,68 @@
 //Copyright (c) 2018 Ultimaker B.V.
 //CuraEngine is released under the terms of the AGPLv3 or higher.
 
+#include "Application.h" //To get settings.
+#include "ExtruderTrain.h"
 #include "Preheat.h"
+#include "Slice.h"
+#include "settings/FlowTempGraph.h"
+#include "settings/types/Ratio.h"
+#include "utils/logoutput.h"
 
 namespace cura 
 {
 
-void Preheat::setConfig(const MeshGroup& meshgroup)
+Duration Preheat::getTimeToGoFromTempToTemp(const size_t extruder, const Temperature& temp_before, const Temperature& temp_after, const bool during_printing)
 {
-    for (int extruder_nr = 0; extruder_nr < meshgroup.getExtruderCount(); extruder_nr++)
-    {
-        assert(meshgroup.getExtruderTrain(extruder_nr) != nullptr);
-        const ExtruderTrain& extruder_train = *meshgroup.getExtruderTrain(extruder_nr);
-        config_per_extruder.emplace_back();
-        Config& config = config_per_extruder.back();
-        double machine_nozzle_cool_down_speed = extruder_train.getSettingInSeconds("machine_nozzle_cool_down_speed");
-        double machine_nozzle_heat_up_speed = extruder_train.getSettingInSeconds("machine_nozzle_heat_up_speed");
-        double material_extrusion_cool_down_speed = extruder_train.getSettingInSeconds("material_extrusion_cool_down_speed");
-        assert(material_extrusion_cool_down_speed < machine_nozzle_heat_up_speed && "The extrusion cooldown speed must be smaller than the heat up speed; otherwise the printing temperature cannot be reached!");
-        config.time_to_cooldown_1_degree[0] = 1.0 / machine_nozzle_cool_down_speed;
-        config.time_to_heatup_1_degree[0] = 1.0 / machine_nozzle_heat_up_speed;
-        config.time_to_cooldown_1_degree[1] = 1.0 / (machine_nozzle_cool_down_speed + material_extrusion_cool_down_speed);
-        config.time_to_heatup_1_degree[1] = 1.0 / (machine_nozzle_heat_up_speed - material_extrusion_cool_down_speed);
-        config.standby_temp = extruder_train.getSettingInSeconds("material_standby_temperature");
-
-        config.min_time_window = extruder_train.getSettingInSeconds("machine_min_cool_heat_time_window");
-
-        config.material_print_temperature = extruder_train.getSettingInDegreeCelsius("material_print_temperature");
-        config.material_print_temperature_layer_0 = extruder_train.getSettingInDegreeCelsius("material_print_temperature_layer_0");
-        config.material_initial_print_temperature = extruder_train.getSettingInDegreeCelsius("material_initial_print_temperature");
-        config.material_final_print_temperature = extruder_train.getSettingInDegreeCelsius("material_final_print_temperature");
-
-        config.flow_dependent_temperature = extruder_train.getSettingBoolean("material_flow_dependent_temperature"); 
-
-        config.flow_temp_graph = extruder_train.getSettingAsFlowTempGraph("material_flow_temp_graph"); // [[0.1,180],[20,230]]
-    }
-}
-
-double Preheat::getTimeToGoFromTempToTemp(int extruder, double temp_before, double temp_after, bool during_printing)
-{
-    Config& config = config_per_extruder[extruder];
-    double time;
+    const Settings& extruder_settings = Application::getInstance().current_slice->scene.extruders[extruder].settings;
+    Duration time;
     if (temp_after > temp_before)
     {
-        time = (temp_after - temp_before) * config.time_to_heatup_1_degree[during_printing];
+        Temperature heat_up_speed = extruder_settings.get<Temperature>("machine_nozzle_heat_up_speed");
+        if (during_printing)
+        {
+            heat_up_speed -= extruder_settings.get<Temperature>("material_extrusion_cool_down_speed");
+        }
+        time = (temp_after - temp_before) / heat_up_speed;
     }
     else
     {
-        time = (temp_before - temp_after) * config.time_to_cooldown_1_degree[during_printing];
+        Temperature cool_down_speed = extruder_settings.get<Temperature>("machine_nozzle_cool_down_speed");
+        if (during_printing)
+        {
+            cool_down_speed += extruder_settings.get<Temperature>("material_extrusion_cool_down_speed");
+        }
+        time = (temp_before - temp_after) / cool_down_speed;
     }
-    return std::max(0.0, time);
+    return std::max(0.0_s, time);
 }
 
-double Preheat::getTemp(unsigned int extruder, double flow, bool is_initial_layer)
+Temperature Preheat::getTemp(const size_t extruder, const Ratio& flow, const bool is_initial_layer)
 {
-    if (is_initial_layer && config_per_extruder[extruder].material_print_temperature_layer_0 != 0)
+    const Settings& extruder_settings = Application::getInstance().current_slice->scene.extruders[extruder].settings;
+    if (is_initial_layer && extruder_settings.get<Temperature>("material_print_temperature_layer_0") != 0)
     {
-        return config_per_extruder[extruder].material_print_temperature_layer_0;
+        return extruder_settings.get<Temperature>("material_print_temperature_layer_0");
     }
-    return config_per_extruder[extruder].flow_temp_graph.getTemp(flow, config_per_extruder[extruder].material_print_temperature, config_per_extruder[extruder].flow_dependent_temperature);
+    return extruder_settings.get<FlowTempGraph>("material_flow_temp_graph").getTemp(flow, extruder_settings.get<Temperature>("material_print_temperature"), extruder_settings.get<bool>("material_flow_dependent_temperature"));
 }
 
 Preheat::WarmUpResult Preheat::getWarmUpPointAfterCoolDown(double time_window, unsigned int extruder, double temp_start, double temp_mid, double temp_end, bool during_printing)
 {
     WarmUpResult result;
-    const Config& config = config_per_extruder[extruder];
-    double time_to_cooldown_1_degree = config.time_to_cooldown_1_degree[during_printing];
-    double time_to_heatup_1_degree = config.time_to_heatup_1_degree[during_printing];
+    const Settings& extruder_settings = Application::getInstance().current_slice->scene.extruders[extruder].settings;
+    Temperature cool_down_speed = extruder_settings.get<Temperature>("machine_nozzle_cool_down_speed");
+    if (during_printing)
+    {
+        cool_down_speed += extruder_settings.get<Temperature>("material_extrusion_cool_down_speed");
+    }
+    const Duration time_to_cooldown_1_degree = 1.0 / cool_down_speed;
+    Temperature heat_up_speed = extruder_settings.get<Temperature>("machine_nozzle_heat_up_speed");
+    if (during_printing)
+    {
+        heat_up_speed -= extruder_settings.get<Temperature>("material_extrusion_cool_down_speed");
+    }
+    const Duration time_to_heatup_1_degree = 1.0 / heat_up_speed;
     result.total_time_window = time_window;
 
     //                    ,temp_end
@@ -124,9 +120,19 @@ Preheat::WarmUpResult Preheat::getWarmUpPointAfterCoolDown(double time_window, u
 Preheat::CoolDownResult Preheat::getCoolDownPointAfterWarmUp(double time_window, unsigned int extruder, double temp_start, double temp_mid, double temp_end, bool during_printing)
 {
     CoolDownResult result;
-    const Config& config = config_per_extruder[extruder];
-    double time_to_cooldown_1_degree = config.time_to_cooldown_1_degree[during_printing];
-    double time_to_heatup_1_degree = config.time_to_heatup_1_degree[during_printing];
+    const Settings& extruder_settings = Application::getInstance().current_slice->scene.extruders[extruder].settings;
+    Temperature cool_down_speed = extruder_settings.get<Temperature>("machine_nozzle_cool_down_speed");
+    if (during_printing)
+    {
+        cool_down_speed += extruder_settings.get<Temperature>("material_extrusion_cool_down_speed");
+    }
+    const Duration time_to_cooldown_1_degree = 1.0 / cool_down_speed;
+    Temperature heat_up_speed = extruder_settings.get<Temperature>("machine_nozzle_heat_up_speed");
+    if (during_printing)
+    {
+        heat_up_speed -= extruder_settings.get<Temperature>("material_extrusion_cool_down_speed");
+    }
+    const Duration time_to_heatup_1_degree = 1.0 / heat_up_speed;
 
     assert(temp_start != -1 && temp_mid != -1 && temp_end != -1 && "temperatures must be initialized!");
 
