@@ -187,9 +187,10 @@ void Infill::multiplyInfill(Polygons& result_polygons, Polygons& result_lines)
 
     const Polygons outline = in_outline.offset(outline_offset);
 
+    // Get the first offset these are mirrored from the original center line
     Polygons result;
     Polygons first_offset;
-    { // calculate [first_offset]
+    {
         const Polygons first_offset_lines = result_lines.offsetPolyLine(offset); // make lines on both sides of the input lines
         const Polygons first_offset_polygons_inward = result_polygons.offset(-offset); // make lines on the inside of the input polygons
         const Polygons first_offset_polygons_outward = result_polygons.offset(offset); // make lines on the other side of the input polygons
@@ -201,19 +202,28 @@ void Infill::multiplyInfill(Polygons& result_polygons, Polygons& result_lines)
         }
     }
     result.add(first_offset);
-    Polygons reference_polygons = first_offset;
-    for (size_t infill_line = 1; infill_line < infill_multiplier / 2; infill_line++) // 2 because we are making lines on both sides at the same time
-    {
-        Polygons extra_offset = reference_polygons.offset(-infill_line_width);
-        result.add(extra_offset);
-        reference_polygons = std::move(extra_offset);
-    }
 
+    // Create the additional offsets from the first offsets, generated earlier, the direction of these offsets is
+    // depended on whether these lines should be connected or not.
+    if (infill_multiplier > 3)
+    {
+        Polygons reference_polygons = first_offset;
+        const size_t multiplier = static_cast<size_t>(infill_multiplier / 2);
+
+        const int extra_offset = mirror_offset ? -infill_line_width : infill_line_width;
+        for (size_t infill_line = 1; infill_line < multiplier; ++infill_line)
+        {
+            Polygons extra_polys = reference_polygons.offset(extra_offset);
+            result.add(extra_polys);
+            reference_polygons = std::move(extra_polys);
+        }
+    }
     if (zig_zaggify)
     {
         result = result.intersection(outline);
     }
 
+    // Remove the original center lines when there are an even number of lines required.
     if (!odd_multiplier)
     {
         result_polygons.clear();
