@@ -95,7 +95,7 @@ void createLayerParts(SliceMeshStorage& mesh, Slicer* slicer)
 
     // OpenMP compatibility fix for GCC <= 8 and GCC >= 9
     // See https://www.gnu.org/software/gcc/gcc-9/porting_to.html, section "OpenMP data sharing"
-#if defined(__GNUC__) && __GNUC__ <= 8
+#if defined(__GNUC__) && __GNUC__ <= 8 && !defined(__clang__)
     #pragma omp parallel for default(none) shared(mesh, slicer) schedule(dynamic)
 #else
     #pragma omp parallel for default(none) shared(mesh, slicer, total_layers) schedule(dynamic)
