@@ -4,13 +4,14 @@
 
 #include "CombPath.h"
 
-namespace cura 
+namespace cura
 {
 
-struct CombPaths : public  std::vector<CombPath> //!< A list of paths alternating between inside a part and outside a part
+class CombPaths : public  std::vector<CombPath> //!< A list of paths alternating between inside a part and outside a part
 {
+public:
     bool throughAir = false; //!< Whether the path is one which moves through air.
-}; 
+};
 
 }//namespace cura
 
