@@ -788,20 +788,20 @@ void SlicerLayer::makePolygons(const Mesh* mesh)
     polygons.removeDegenerateVerts(); // remove verts connected to overlapping line segments
 }
 
-Slicer::Slicer(Mesh* i_mesh, const coord_t thickness, const size_t slice_layer_count, 
+Slicer::Slicer(Mesh* i_mesh, const coord_t thickness, const size_t slice_layer_count,
                bool use_variable_layer_heights, std::vector<AdaptiveLayer>* adaptive_layers)
     : mesh(i_mesh)
 {
     const SlicingTolerance slicing_tolerance = mesh->settings.get<SlicingTolerance>("slicing_tolerance");
-    const coord_t initial_layer_thickness = 
+    const coord_t initial_layer_thickness =
         Application::getInstance().current_slice->scene.current_mesh_group->settings.get<coord_t>("layer_height_0");
 
     assert(slice_layer_count > 0);
 
     TimeKeeper slice_timer;
 
-    layers = 
-        buildLayersWithHeight(slice_layer_count, slicing_tolerance, initial_layer_thickness, thickness, 
+    layers =
+        buildLayersWithHeight(slice_layer_count, slicing_tolerance, initial_layer_thickness, thickness,
             use_variable_layer_heights, adaptive_layers);
 
 
@@ -817,7 +817,7 @@ Slicer::Slicer(Mesh* i_mesh, const coord_t thickness, const size_t slice_layer_c
 }
 
 void Slicer::buildSegments(const Mesh& mesh, const std::vector<std::pair<int32_t, int32_t>> &zbbox,
-    std::vector<SlicerLayer>& layers) 
+    std::vector<SlicerLayer>& layers)
 {
     // OpenMP
 #pragma omp parallel for default(none) shared(mesh, zbbox, layers)
@@ -848,48 +848,80 @@ void Slicer::buildSegments(const Mesh& mesh, const std::vector<std::pair<int32_t
             s.endVertex = nullptr;
             int end_edge_idx = -1;
 
-            if (p0.z < z && p1.z >= z && p2.z >= z)
-            {
-                s = project2D(p0, p2, p1, z);
-                end_edge_idx = 0;
-                if (p1.z == z)
+            /*
+            Now see if the triangle intersects the layer, and if so, where.
+
+            Edge cases are important here:
+            - If all three vertices of the triangle are exactly on the layer,
+              don't count the triangle at all, because if the model is
+              watertight, there will be adjacent triangles on all 3 sides that
+              are not flat on the layer.
+            - If two of the vertices are exactly on the layer, only count the
+              triangle if the last vertex is going up. We can't count both
+              upwards and downwards triangles here, because if the model is
+              manifold there will always be an adjacent triangle that is going
+              the other way and you'd get double edges. You would also get one
+              layer too many if the total model height is an exact multiple of
+              the layer thickness. Between going up and going down, we need to
+              choose the triangles going up, because otherwise the first layer
+              of where the model starts will be empty and the model will float
+              in mid-air. We'd much rather let the last layer be empty in that
+              case.
+            - If only one of the vertices is exactly on the layer, the
+              intersection between the triangle and the plane would be a point.
+              We can't print points and with a manifold model there would be
+              line segments adjacent to the point on both sides anyway, so we
+              need to discard this 0-length line segment then.
+            - Vertices in ccw order if look from outside.
+            */
+
+            if (p0.z < z && p1.z > z && p2.z > z)              //  1_______2
+            {                                                  //   \     /
+                s = project2D(p0, p2, p1, z);                  //------------- z
+                end_edge_idx = 0;                              //     \ /
+            }                                                  //      0
+
+            else if (p0.z > z && p1.z <= z && p2.z <= z)       //      0
+            {                                                  //     / \      .
+                s = project2D(p0, p1, p2, z);                  //------------- z
+                end_edge_idx = 2;                              //   /     \    .
+                if (p2.z == z)                                 //  1_______2
+                {
+                     s.endVertex = &v2;
+                }
+            }
+
+            else if (p1.z < z && p0.z > z && p2.z > z)         //  0_______2
+            {                                                  //   \     /
+                s = project2D(p1, p0, p2, z);                  //------------- z
+                end_edge_idx = 1;                              //     \ /
+            }                                                  //      1
+
+            else if (p1.z > z && p0.z <= z && p2.z <= z)       //      1
+            {                                                  //     / \      .
+                s = project2D(p1, p2, p0, z);                  //------------- z
+                end_edge_idx = 0;                              //   /     \    .
+                if (p0.z == z)                                 //  0_______2
+                {
+                     s.endVertex = &v0;
+                }
+            }
+
+            else if (p2.z < z && p1.z > z && p0.z > z)         //  0_______1
+            {                                                  //   \     /
+                s = project2D(p2, p1, p0, z);                  //------------- z
+                end_edge_idx = 2;                              //     \ /
+            }                                                  //      2
+
+            else if (p2.z > z && p1.z <= z && p0.z <= z)       //      2
+            {                                                  //     / \      .
+                s = project2D(p2, p0, p1, z);                  //------------- z
+                end_edge_idx = 1;                              //   /     \    .
+                if (p1.z == z)                                 //  0_______1
                 {
                     s.endVertex = &v1;
                 }
             }
-            else if (p0.z > z && p1.z < z && p2.z < z)
-            {
-                s = project2D(p0, p1, p2, z);
-                end_edge_idx = 2;
-            }
-            else if (p1.z < z && p0.z >= z && p2.z >= z)
-            {
-                s = project2D(p1, p0, p2, z);
-                end_edge_idx = 1;
-                if (p2.z == z)
-                {
-                    s.endVertex = &v2;
-                }
-            }
-            else if (p1.z > z && p0.z < z && p2.z < z)
-            {
-                s = project2D(p1, p2, p0, z);
-                end_edge_idx = 0;
-            }
-            else if (p2.z < z && p1.z >= z && p0.z >= z)
-            {
-                s = project2D(p2, p1, p0, z);
-                end_edge_idx = 2;
-                if (p0.z == z)
-                {
-                    s.endVertex = &v0;
-                }
-            }
-            else if (p2.z > z && p1.z < z && p0.z < z)
-            {
-                s = project2D(p2, p0, p1, z);
-                end_edge_idx = 1;
-            }
             else
             {
                 //Not all cases create a segment, because a point of a face could create just a dot, and two touching faces
@@ -1002,7 +1034,7 @@ void Slicer::makePolygons(Mesh& mesh, SlicingTolerance slicing_tolerance, std::v
 }
 
 
-std::vector<std::pair<int32_t, int32_t>> Slicer::buildZHeightsForFaces(const Mesh& mesh) 
+std::vector<std::pair<int32_t, int32_t>> Slicer::buildZHeightsForFaces(const Mesh& mesh)
 {
     std::vector<std::pair<int32_t, int32_t>> zHeights;
     zHeights.reserve(mesh.faces.size());
@@ -1018,23 +1050,23 @@ std::vector<std::pair<int32_t, int32_t>> Slicer::buildZHeightsForFaces(const Mes
         Point3 p1 = v1.p;
         Point3 p2 = v2.p;
 
-        // find the minimum and maximum z point		
+        // find the minimum and maximum z point
         int32_t minZ = p0.z;
-        if (p1.z < minZ) 
+        if (p1.z < minZ)
         {
             minZ = p1.z;
         }
-        if (p2.z < minZ) 
+        if (p2.z < minZ)
         {
             minZ = p2.z;
         }
 
         int32_t maxZ = p0.z;
-        if (p1.z > maxZ) 
+        if (p1.z > maxZ)
         {
             maxZ = p1.z;
         }
-        if (p2.z > maxZ) 
+        if (p2.z > maxZ)
         {
             maxZ = p2.z;
         }
@@ -1061,7 +1093,7 @@ coord_t Slicer::interpolate(const coord_t x, const coord_t x0, const coord_t x1,
 {
     const coord_t dx_01 = x1 - x0;
     coord_t num = (y1 - y0) * (x - x0);
-    num += num > 0 ? dx_01 / 2 : -dx_01 / 2; // add in offset to round result
+    num += num > 0 ? dx_01 / 4 : -dx_01 / 4; // add in offset to round result
     return y0 + num / dx_01;
 }
 
