@@ -1,16 +1,18 @@
-/** Copyright (C) 2016 Ultimaker - Released under terms of the AGPLv3 License */
+//Copyright (c) 2018 Ultimaker B.V.
+//CuraEngine is released under the terms of the AGPLv3 or higher.
+
 #ifndef UTILS_AABB_H
 #define UTILS_AABB_H
 
-
-#include "intpoint.h"
-#include "polygon.h"
-
+#include "IntPoint.h"
 
 namespace cura
 {
-    
-    
+
+class ConstPolygonRef;
+class Polygon;
+class Polygons;
+
 /* Axis aligned boundary box */
 class AABB
 {
@@ -57,6 +59,17 @@ public:
      */
     void include(Point point);
 
+    /*!
+     * \brief Includes the specified bounding box in the bounding box.
+     * 
+     * The bounding box is expanded to include the other bounding box.
+     * 
+     * This performs a union on two bounding boxes.
+     * 
+     * \param other The bounding box to include in this one.
+     */
+    void include(const AABB other);
+
     /*!
      * Expand the borders of the bounding box in each direction with the given amount
      * 
@@ -64,15 +77,6 @@ public:
      */
     void expand(int dist);
 
-    /*!
-     * Expand the bounding box to a round increment.
-     *
-     * The coordinates are rounded to the specified increment, but the AABB can
-     * never become smaller with this operation.
-     * \param increment The size of the grid cells to round the bounding box to.
-     */
-    void round(const coord_t increment);
-
     /*!
      * Generate a square polygon which coincides with this aabb
      * \return the polygon of this aabb
